OptionParser-class: Option Parser

OptionParser-classR Documentation

Option Parser

Description

Option Parser

Slots

usage

The program usage message that will printed out if parse_args() finds a help option, ⁠\%prog⁠ is substituted with the value of the prog argument.

options

A list of of OptionParserOption instances that will define how parse_args() reacts to command line options. OptionParserOption instances are usually created by make_option() and can also be added to an existing OptionParser instance via the add_option() function.

description

Additional text for print_help() to print out between usage statement and options statement

epilogue

Additional text for print_help() to print out after the options statement

formatter

A function that print_help() will use to print out after the options statement. Default is IndentedHelpFormatter(). This package also provides the builtin formatter TitledHelpFormatter().

See Also

OptionParserOption


optparse documentation built on April 17, 2026, 9:06 a.m.