| OptionParser-class | R Documentation |
Option Parser
usageThe program usage message that will printed out if
parse_args() finds a help option, \%prog is substituted with the
value of the prog argument.
optionsA list of of OptionParserOption instances that will
define how parse_args() reacts to command line options.
OptionParserOption instances are usually created by make_option()
and can also be added to an existing OptionParser instance via the
add_option() function.
descriptionAdditional text for print_help() to print out between
usage statement and options statement
epilogueAdditional text for print_help() to print out after
the options statement
formatterA function that print_help() will use to print out after
the options statement. Default is IndentedHelpFormatter(). This
package also provides the builtin formatter TitledHelpFormatter().
OptionParserOption
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.